@@ -2,7 +2,7 @@ public class OBTest
 {
   public OBTest()
   {
-    System.loadLibrary("openbabel");
+    System.loadLibrary("openbabeljni");
   }
 
   public void run()
@@ -23,4 +23,4 @@ public class OBTest
 
     test.run();
   }
-}
\ No newline at end of file
+}
