@@ -419,7 +419,6 @@ For more detailed information see:\n\
 http://openbabel.sourceforge.net/wiki/Windows_GUI\n\n \
 OpenBabel version "));
 	 msg << BABEL_VERSION;
-	msg << " development snapshot March 2005";
     wxMessageBox(msg, _T("About OpenBabelGUI"), wxOK | wxICON_INFORMATION | wxCENTER, this);
 }
 ///////////////////////////////////////////
@@ -566,7 +565,7 @@ void OBGUIFrame::OnGetInputFile(wxCommandEvent& WXUNUSED(event))
 {
 	wxFileDialog dialog(this,_T("Choose Input File"),m_InFileBasePath,_T(""),
 			GetFilter(m_pInFormat) + InputFilterString,
-			wxMULTIPLE | wxFILE_MUST_EXIST | wxHIDE_READONLY );
+			wxMULTIPLE | wxFILE_MUST_EXIST);
 	if(dialog.ShowModal() == wxID_OK)
 	{
 //		m_pInFilename->Clear();
@@ -789,7 +788,7 @@ void OBGUIFrame::DoOptions(OpenBabel::OBConversion& Conv)
 		if(m_pAPIOptsPanel->SetOptions(apiConv, OBConversion::GENOPTIONS))
 		{
 			apiConv.SetOutFormat(pAPI);
-			apiConv.Write(NULL);
+      apiConv.Write(NULL, &std::cout);
 		}
 	}
 	m_pGenOptsPanel->SetOptions(Conv, OBConversion::GENOPTIONS);
