@@ -950,8 +950,8 @@ namespace OpenBabel
       string _a(a);
       string _b(b);
       for (unsigned int idx=0; idx < parameter.size(); ++idx) {
-        if (((_a == parameter[idx]._a) && (_b == parameter[idx]._b)) && (type == parameter[idx].ipar5) || 
-            ((_a == parameter[idx]._b) && (_b == parameter[idx]._a)) && (type == parameter[idx].ipar5)) {
+        if (((_a == parameter[idx]._a) && (_b == parameter[idx]._b) && (type == parameter[idx].ipar5)) || 
+            ((_a == parameter[idx]._b) && (_b == parameter[idx]._a) && (type == parameter[idx].ipar5))) {
           par = &parameter[idx];
           return par;
         }
@@ -963,8 +963,8 @@ namespace OpenBabel
       string _b(b);
       string _c(c);
       for (unsigned int idx=0; idx < parameter.size(); ++idx) {
-        if (((_a == parameter[idx]._a) && (_b == parameter[idx]._b) && (_c == parameter[idx]._c)) && (type == parameter[idx].ipar5)|| 
-            ((_a == parameter[idx]._c) && (_b == parameter[idx]._b) && (_c == parameter[idx]._a)) && (type == parameter[idx].ipar5)) {
+        if (((_a == parameter[idx]._a) && (_b == parameter[idx]._b) && (_c == parameter[idx]._c) && (type == parameter[idx].ipar5))|| 
+            ((_a == parameter[idx]._c) && (_b == parameter[idx]._b) && (_c == parameter[idx]._a) && (type == parameter[idx].ipar5))) {
           par = &parameter[idx];
           return par;
         }
@@ -978,9 +978,9 @@ namespace OpenBabel
 
     for (unsigned int idx=0; idx < parameter.size(); ++idx) {
       if (((_a == parameter[idx]._a) && (_b == parameter[idx]._b) && (_c == parameter[idx]._c) && 
-           (_d == parameter[idx]._d)) && (type == parameter[idx].ipar5) || 
+           (_d == parameter[idx]._d) && (type == parameter[idx].ipar5)) || 
           ((_a == parameter[idx]._d) && (_b == parameter[idx]._c) && (_c == parameter[idx]._b) && 
-           (_d == parameter[idx]._a)) && (type == parameter[idx].ipar5)) {
+           (_d == parameter[idx]._a) && (type == parameter[idx].ipar5))) {
         par = &parameter[idx];
         return par;
       }
