@@ -12,39 +12,38 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 ***********************************************************************/
+#include <openbabel/babelconfig.h>
 
-#include "mol.h"
-#include "obconversion.h"
-#include "obmolecformat.h"
+#include <openbabel/obmolecformat.h>
 
 using namespace std;
 namespace OpenBabel
 {
 
-class BallStickFormat : public OBMoleculeFormat
-{
-public:
+  class BallStickFormat : public OBMoleculeFormat
+  {
+  public:
     //Register this format type ID
     BallStickFormat()
     {
-        OBConversion::RegisterFormat("bs",this);
+      OBConversion::RegisterFormat("bs",this);
     }
 
     virtual const char* Description() //required
     {
-        return
-            "Ball and Stick format\n \
+      return
+        "Ball and Stick format\n \
             No comments yet\n";
     };
 
-  virtual const char* SpecificationURL()
-  {return "http://www.orc.uni-linz.ac.at/mueller/ball_and_stick.shtml"; };
+    virtual const char* SpecificationURL()
+    {return "http://www.orc.uni-linz.ac.at/mueller/ball_and_stick.shtml"; };
 
     //Flags() can return be any the following combined by | or be omitted if none apply
     // NOTREADABLE  READONEONLY  NOTWRITABLE  WRITEONEONLY
     virtual unsigned int Flags()
     {
-        return READONEONLY | WRITEONEONLY;
+      return READONEONLY | WRITEONEONLY;
     };
 
     //*** This section identical for most OBMol conversions ***
@@ -52,19 +51,19 @@ public:
     /// The "API" interface functions
     virtual bool ReadMolecule(OBBase* pOb, OBConversion* pConv);
     virtual bool WriteMolecule(OBBase* pOb, OBConversion* pConv);
-};
-//***
+  };
+  //***
 
-//Make an instance of the format class
-BallStickFormat theBallStickFormat;
+  //Make an instance of the format class
+  BallStickFormat theBallStickFormat;
 
-/////////////////////////////////////////////////////////////////
-bool BallStickFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
-{
+  /////////////////////////////////////////////////////////////////
+  bool BallStickFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
+  {
 
-    OBMol* pmol = dynamic_cast<OBMol*>(pOb);
+    OBMol* pmol = pOb->CastAndClear<OBMol>();
     if(pmol==NULL)
-        return false;
+      return false;
 
     //Define some references so we can use the old parameter names
     istream &ifs = *pConv->GetInStream();
@@ -75,9 +74,9 @@ bool BallStickFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
     char buffer[BUFF_SIZE];
 
     if (!ifs.getline(buffer,BUFF_SIZE))
-        return(false);
+      return(false);
     if (!ifs.getline(buffer,BUFF_SIZE))
-        return(false);
+      return(false);
     sscanf(buffer,"%d",&natoms);
     mol.ReserveAtoms(natoms);
     mol.BeginModify();
@@ -88,14 +87,14 @@ bool BallStickFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
     vector<string>::iterator j;
 
     for (i = 1; i <= natoms;i ++)
-    {
+      {
         if (!ifs.getline(buffer,BUFF_SIZE))
-            return(false);
+          return(false);
         tokenize(vs,buffer);
         if (vs.size() < 4)
-            return(false);
+          return(false);
         if (vs[0].size() > 1)
-            vs[0][1] = tolower(vs[0][1]);
+          vs[0][1] = tolower(vs[0][1]);
         atom = mol.NewAtom();
         x = atof((char*)vs[1].c_str());
         y = atof((char*)vs[2].c_str());
@@ -104,26 +103,26 @@ bool BallStickFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
         atom->SetAtomicNum(etab.GetAtomicNum(vs[0].c_str()));
 
         for (j = vs.begin()+4;j != vs.end();j++)
-            mol.AddBond(atom->GetIdx(),atoi((char*)j->c_str()),1);
-    }
+          mol.AddBond(atom->GetIdx(),atoi((char*)j->c_str()),1);
+      }
     
     // clean out any remaining blank lines
     while(ifs.peek() != EOF && ifs.good() && 
-	  (ifs.peek() == '\n' || ifs.peek() == '\r'))
+          (ifs.peek() == '\n' || ifs.peek() == '\r'))
       ifs.getline(buffer,BUFF_SIZE);
 
     mol.EndModify();
     mol.SetTitle(title);
     return(true);
-}
+  }
 
-////////////////////////////////////////////////////////////////
+  ////////////////////////////////////////////////////////////////
 
-bool BallStickFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
-{
+  bool BallStickFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
+  {
     OBMol* pmol = dynamic_cast<OBMol*>(pOb);
     if(pmol==NULL)
-        return false;
+      return false;
 
     //Define some references so we can use the old parameter names
     ostream &ofs = *pConv->GetOutStream();
@@ -133,23 +132,23 @@ bool BallStickFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
     char buffer[BUFF_SIZE];
 
     if (strlen(mol.GetTitle()) > 0)
-        ofs << mol.GetTitle() << endl;
+      ofs << mol.GetTitle() << endl;
     else
-        ofs << "Untitled" << endl;
+      ofs << "Untitled" << endl;
 
     snprintf(buffer,BUFF_SIZE,"%d",mol.NumAtoms());
     ofs << buffer << endl;
 
     OBAtom *atom,*nbr;
-    vector<OBNodeBase*>::iterator i;
-    vector<OBEdgeBase*>::iterator j;
+    vector<OBAtom*>::iterator i;
+    vector<OBBond*>::iterator j;
 
     for(atom = mol.BeginAtom(i);atom;atom = mol.NextAtom(i))
-    {
+      {
         strncpy(tmptype,etab.GetSymbol(atom->GetAtomicNum()), sizeof(tmptype));
         tmptype[15] = '\0';
         if (strlen(tmptype) > 1)
-            tmptype[1] = toupper(tmptype[1]);
+          tmptype[1] = toupper(tmptype[1]);
         snprintf(buffer,BUFF_SIZE,"%-3s %8.4f  %8.4f  %8.4f",
                  tmptype,
                  atom->GetX(),
@@ -157,14 +156,14 @@ bool BallStickFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
                  atom->GetZ());
         ofs << buffer;
         for (nbr = atom->BeginNbrAtom(j);nbr;nbr = atom->NextNbrAtom(j))
-        {
+          {
             sprintf(buffer,"%6d",nbr->GetIdx());
             ofs << buffer;
-        }
+          }
         ofs << endl;
-    }
+      }
 
     return(true);
-}
+  }
 
 } //namespace OpenBabel
