@@ -15,77 +15,56 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 ***********************************************************************/
 
-#include "mol.h"
-#include "obconversion.h"
+#include <openbabel/babelconfig.h>
+#include <openbabel/obmolecformat.h>
 #include <stdlib.h>
 
 using namespace std;
 namespace OpenBabel
 {
 
-class CHTFormat : public OBFormat
-{
-public:
+  class CHTFormat : public OBMoleculeFormat
+  {
+  public:
     //Register this format type ID
     CHTFormat()
     {
-        OBConversion::RegisterFormat("cht",this);
+      OBConversion::RegisterFormat("cht",this);
     }
 
     virtual const char* Description() //required
     {
-        return
-            "Chemtool format\n \
+      return
+        "Chemtool format\n \
             No comments yet\n";
     };
 
-  virtual const char* SpecificationURL()
-  {return "http://ruby.chemie.uni-freiburg.de/~martin/chemtool/chemtool.html";}; //optional
+    virtual const char* SpecificationURL()
+    {return "http://ruby.chemie.uni-freiburg.de/~martin/chemtool/chemtool.html";}; //optional
 
     //Flags() can return be any the following combined by | or be omitted if none apply
     // NOTREADABLE  READONEONLY  NOTWRITABLE  WRITEONEONLY
     virtual unsigned int Flags()
     {
-        return NOTREADABLE;
+      return NOTREADABLE;
     };
 
     ////////////////////////////////////////////////////
     /// The "API" interface functions
     virtual bool WriteMolecule(OBBase* pOb, OBConversion* pConv);
 
-    ////////////////////////////////////////////////////
-    /// The "Convert" interface functions
-    virtual bool WriteChemObject(OBConversion* pConv)
-    {
-        //Retrieve the target OBMol
-        OBBase* pOb = pConv->GetChemObject();
-        OBMol* pmol = dynamic_cast<OBMol*> (pOb);
-        bool ret=false;
-        if(pmol)
-            ret=WriteMolecule(pmol,pConv);
+  };
 
-        std::string auditMsg = "OpenBabel::Write molecule ";
-        std::string description(Description());
-        auditMsg += description.substr( 0, description.find('\n') );
-        obErrorLog.ThrowError(__FUNCTION__,
-                              auditMsg,
-                              obAuditMsg);
+  //Make an instance of the format class
+  CHTFormat theCHTFormat;
 
-        delete pOb;
-        return ret;
-    };
-};
+  /////////////////////////////////////////////////////////////////
 
-//Make an instance of the format class
-CHTFormat theCHTFormat;
-
-/////////////////////////////////////////////////////////////////
-
-bool CHTFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
-{
+  bool CHTFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
+  {
     OBMol* pmol = dynamic_cast<OBMol*>(pOb);
     if(pmol==NULL)
-        return false;
+      return false;
 
     //Define some references so we can use the old parameter names
     ostream &ofs = *pConv->GetOutStream();
@@ -104,63 +83,63 @@ bool CHTFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
     // get the geometry
     w = 0;
     h = 0;
-    vector<OBNodeBase*>::iterator i;
+    vector<OBAtom*>::iterator i;
     for (atom = mol.BeginAtom(i); atom; atom = mol.NextAtom(i))
-    {
+      {
         x = (int)(atom->GetX()) * conv_factor;
         y = (int)(atom->GetY()) * conv_factor;
         if (x > w)
-            w = x;
+          w = x;
         if (y > h)
-            h = y;
+          h = y;
         if (atom->GetAtomicNum() != 6)
-            natoms++;
-    }
+          natoms++;
+      }
     ofs << "geometry " << w * 1.1 << " " << h * 1.1 << endl;
 
     // write out bonds
     ofs << "bonds "<< mol.NumBonds() << endl;
-    vector<OBEdgeBase*>::iterator j;
+    vector<OBBond*>::iterator j;
     for(bond = mol.BeginBond(j); bond; bond = mol.NextBond(j))
-    {
+      {
         bondtype = 0;
         atom1 = bond->GetBeginAtom();
         atom2 = bond->GetEndAtom();
         if (bond->GetBO() == 2)
-            bondtype = 1;
+          bondtype = 1;
         if (bond->GetBO() == 3)
-            bondtype = 3;
+          bondtype = 3;
         // FIXME: use flag-info, too
         snprintf(buffer, BUFF_SIZE, "%d\t%d\t%d\t%d\t%1d",
-                (int)floor(atom1->GetX() * conv_factor + 0.5),
-                (int)floor(atom1->GetY() * conv_factor + 0.5),
-                (int)floor(atom2->GetX() * conv_factor + 0.5),
-                (int)floor(atom2->GetY() * conv_factor + 0.5),
-                bondtype);
+                 (int)floor(atom1->GetX() * conv_factor + 0.5),
+                 (int)floor(atom1->GetY() * conv_factor + 0.5),
+                 (int)floor(atom2->GetX() * conv_factor + 0.5),
+                 (int)floor(atom2->GetY() * conv_factor + 0.5),
+                 bondtype);
         ofs << buffer << endl;
-    }
+      }
 
     // start over, write additional atoms
     ofs << "atoms " << natoms << endl;
     for (atom = mol.BeginAtom(i); atom; atom = mol.NextAtom(i))
-    {
+      {
         // Carbon does not need to be treated
         if (atom->GetAtomicNum() != 6)
-        {
+          {
             snprintf(buffer, BUFF_SIZE, "%d\t%d\t%s\t%d",
-                    (int)floor(atom->GetX() * conv_factor + 0.5),
-                    (int)floor(atom->GetY() * conv_factor + 0.5),
-                    etab.GetSymbol(atom->GetAtomicNum()),
-                    -1 // assume centered Text
-                   );
+                     (int)floor(atom->GetX() * conv_factor + 0.5),
+                     (int)floor(atom->GetY() * conv_factor + 0.5),
+                     etab.GetSymbol(atom->GetAtomicNum()),
+                     -1 // assume centered Text
+                     );
             ofs << buffer << endl;
-        }
-    }
+          }
+      }
 
     // We don't have any splines to write
     ofs << "splines 0" << endl;
 
     return true;
-}
+  }
 
 } //namespace OpenBabel
