@@ -50,79 +50,58 @@ GNU General Public License for more details.
 	 *** But now handled by a command line option in new framework.
 */
 
-#include "mol.h"
-#include "obconversion.h"
+#include <openbabel/babelconfig.h>
+#include <openbabel/obmolecformat.h>
 
 using namespace std;
 namespace OpenBabel
 {
 
-class GROMOS96Format : public OBFormat
-{
-public:
+  class GROMOS96Format : public OBMoleculeFormat
+  {
+  public:
     //Register this format type ID
     GROMOS96Format()
     {
-        OBConversion::RegisterFormat("gr96",this);
+      OBConversion::RegisterFormat("gr96",this);
     }
 
-  virtual const char* Description() //required
-  {
-    return
-      "GROMOS96 format\n \
+    virtual const char* Description() //required
+    {
+      return
+        "GROMOS96 format\n \
        Write Options e.g. -xn\n\
         n output nm (not Angstroms)\n";
-  };
+    };
 
     virtual const char* SpecificationURL()
     {
-        return "";
+      return "";
     }; //optional
 
     //Flags() can return be any the following combined by | or be omitted if none apply
     // NOTREADABLE  READONEONLY  NOTWRITABLE  WRITEONEONLY
     virtual unsigned int Flags()
     {
-        return NOTREADABLE | WRITEONEONLY;
+      return NOTREADABLE | WRITEONEONLY;
     };
 
     ////////////////////////////////////////////////////
     /// The "API" interface functions
     virtual bool WriteMolecule(OBBase* pOb, OBConversion* pConv);
 
-    ////////////////////////////////////////////////////
-    /// The "Convert" interface functions
-    virtual bool WriteChemObject(OBConversion* pConv)
-    {
-        //Retrieve the target OBMol
-        OBBase* pOb = pConv->GetChemObject();
-        OBMol* pmol = dynamic_cast<OBMol*> (pOb);
-        bool ret=false;
-        if(pmol)
-            ret=WriteMolecule(pmol,pConv);
+  };
 
-	std::string auditMsg = "OpenBabel::Write molecule ";
-	std::string description(Description());
-        auditMsg += description.substr( 0, description.find('\n') );
-        obErrorLog.ThrowError(__FUNCTION__,
-                              auditMsg,
-                              obAuditMsg);
+  //Make an instance of the format class
+  GROMOS96Format theGROMOS96Format;
 
-        delete pOb;
-        return ret;
-    };
-};
+  ////////////////////////////////////////////////////////////////
 
-//Make an instance of the format class
-GROMOS96Format theGROMOS96Format;
-
-////////////////////////////////////////////////////////////////
-
-bool GROMOS96Format::WriteMolecule(OBBase* pOb, OBConversion* pConv)
-{
+  bool GROMOS96Format::WriteMolecule(OBBase* pOb, OBConversion* pConv)
+  {
     OBMol* pmol = dynamic_cast<OBMol*>(pOb);
     if(pmol==NULL)
-        return false;
+      return false;
 
     //Define some references so we can use the old parameter names
     ostream &ofs = *pConv->GetOutStream();
@@ -143,25 +122,25 @@ bool GROMOS96Format::WriteMolecule(OBBase* pOb, OBConversion* pConv)
 
     OBAtom *atom;
     OBResidue *res;
-    vector<OBNodeBase*>::iterator i;
+    vector<OBAtom*>::iterator i;
 
     for(atom = mol.BeginAtom(i);atom;atom = mol.NextAtom(i))
-    {
-      if ( (res = atom->GetResidue()) )
-        {
+      {
+        if ( (res = atom->GetResidue()) )
+          {
             // 16 = sizeof(res_name) and sizeof(type_name)
             strncpy(res_name,(char*)res->GetName().c_str(), 16);
             res_name[15] = '\0';
             strncpy(type_name,(char*)res->GetAtomID(atom).c_str(), 16);
             type_name[15] = '\0';
             res_num = res->GetNum();
-        }
+          }
         else
-        {
+          {
             strncpy(type_name,etab.GetSymbol(atom->GetAtomicNum()), 16);
             strcpy(res_name,"UNK");
             res_num = 1;
-        }
+          }
 
         snprintf(buffer, BUFF_SIZE, "%5d %5s %5s %6d %15.5f %15.5f %15.5f\n",
                 res_num,res_name,type_name,atom->GetIdx(),
@@ -169,15 +148,15 @@ bool GROMOS96Format::WriteMolecule(OBBase* pOb, OBConversion* pConv)
         ofs << buffer;
 
         if (!(atom->GetIdx()%10))
-        {
+          {
             sprintf(buffer,"# %d\n",atom->GetIdx());
             ofs << buffer;
-        }
-    }
+          }
+      }
 
     ofs << "END\n";
 
     return(true);
-}
+  }
 
 } //namespace OpenBabel
