@@ -445,10 +445,15 @@ bool InChIFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
           stereo.central_atom = patom->GetIdx()-1;
           stereo.type = INCHI_StereoType_Tetrahedral;
           OBChiralData* cd=(OBChiralData*)patom->GetData(OBGenericDataType::ChiralData);
+          if (!cd) {
+            obErrorLog.ThrowError(__FUNCTION__, molID.str()+": Tetrahedral stereo info not available", obInfo);
+            break;
+          }
+            
           vector<unsigned int>refs = cd->GetAtom4Refs(input);
           if(refs.size()<4)
           {
-            obErrorLog.ThrowError(__FUNCTION__, "Tetrahedral stereo info not available", obWarning);
+            obErrorLog.ThrowError(__FUNCTION__, molID.str()+": Tetrahedral stereo info not available", obInfo);
             break;
           }
           for(int i=0;i<4; ++i)
@@ -909,7 +914,7 @@ char* InChIFormat::GetInChIOptions(OBConversion* pConv, bool Reading)
     string ch(" -");
 #endif
     string sopts;
-    for(int i=0;i<optsvec.size();++i)
+    for(unsigned int i=0;i<optsvec.size();++i)
       sopts += ch + optsvec[i];
     opts = new char[strlen(sopts.c_str())+1]; //has to be char, not const char
     return strcpy(opts, sopts.c_str());
