@@ -217,6 +217,11 @@ namespace OpenBabel
           } // end (OPTIMIZATION CONVERGED)
       } // end while
 
+    if (mol.NumAtoms() == 0) { // e.g., if we're at the end of a file PR#1737209
+      mol.EndModify();
+      return false;
+    }
+
     if (!pConv->IsOption("b",OBConversion::INOPTIONS))
       mol.ConnectTheDots();
     if (!pConv->IsOption("s",OBConversion::INOPTIONS) && !pConv->IsOption("b",OBConversion::INOPTIONS))
@@ -252,8 +257,8 @@ namespace OpenBabel
     ostream &ofs = *pConv->GetOutStream();
     OBMol &mol = *pmol;
 
-    unsigned int i;
-    OBAtom *atom;
+    // unsigned int i;
+    // OBAtom *atom;
 
     ofs << "$comment" << endl;
     ofs << mol.GetTitle() << endl;
