@@ -13,9 +13,8 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 ***********************************************************************/
-#include "mol.h"
-#include "obconversion.h"
-#include "xml.h"
+#include <openbabel/babelconfig.h>
+#include <openbabel/xml.h>
 
 #ifdef WIN32
 #pragma warning (disable : 4800)
@@ -30,7 +29,7 @@ class PubChemFormat : public XMLMoleculeFormat
 public:
 	PubChemFormat() 
 	{
-		OBConversion::RegisterFormat("pc", this);
+    OBConversion::RegisterFormat("pc", this, "chemical/x-ncbi-asn1-xml");
 		XMLConversion::RegisterXMLFormat(this);
 	}
 	virtual const char* NamespaceURI()const{return "http://www.ncbi.nlm.nih.gov";}
@@ -45,10 +44,12 @@ Minimal extraction of chemical structure information only.\n \
   virtual const char* SpecificationURL()
   {return "ftp://ftp.ncbi.nlm.nih.gov/pubchem/data_spec/pubchem.xsd";};
 
+  virtual const char* GetMIMEType() 
+  { return "chemical/x-ncbi-asn1-xml"; };
 
   virtual unsigned int Flags()
   {
-      return NOTWRITABLE;
+    return (READXML | NOTWRITABLE);
   };
 
 	virtual bool DoElement(const string& name);
