@@ -18,6 +18,7 @@ GNU General Public License for more details.
 ***********************************************************************/
 // Definition of OBConversion routines
 #include <openbabel/babelconfig.h>
+#include <climits>
 
 #ifdef _WIN32
 	#pragma warning (disable : 4786)
@@ -38,7 +39,6 @@ GNU General Public License for more details.
 #include <map>
 
 #include <openbabel/obconversion.h>
-#include "openbabel/lineend.h"
 
 #ifdef HAVE_LIBZ
 #include "zipstream.h"
@@ -217,7 +217,7 @@ namespace OpenBabel {
     EndNumber(0), Count(-1), m_IsFirstInput(true), m_IsLast(true),
     MoreFilesToCome(false), OneObjectOnly(false), CheckedForGzip(false),
     NeedToFreeInStream(false), NeedToFreeOutStream(false), 
-    pOb1(NULL), pAuxConv(NULL)
+    pOb1(NULL), pAuxConv(NULL),pLineEndBuf(NULL)
   {
     pInStream=is;
     pOutStream=os;
@@ -277,7 +277,7 @@ namespace OpenBabel {
     CheckedForGzip = o.CheckedForGzip;
     NeedToFreeInStream = o.NeedToFreeInStream;
     NeedToFreeOutStream = o.NeedToFreeOutStream;
-
+    pLineEndBuf    = o.pLineEndBuf;
     pAuxConv       = NULL;
   }
   ///////////////////////////////////////////////
@@ -479,21 +479,12 @@ namespace OpenBabel {
     //and receives characters this stream's original rdbuf. 
     //It filters them, converting CRLF and CR line endings to LF.
     //seek and tellg requests to the stream are passed through to the original
-    //rdbuf.
-    //streambuf objects cannot be member variables and so need to be made here.
-    //Because FilteringInputStreambuf has to be at this level to remain
-    //in scope during Convert(), it is always constructed, but is only used in
-    //with formats with non-binary and which are not XML (which should not be 
-    //sensitive to line endings anyway).
+    //rdbuf. A FilteringInputStreambuf is installed only for appropriate formats
+    //- not for binary or XML formats - if not already present.
+    InstallStreamFilter();
 
-    FilteringInputStreambuf< LineEndingExtractor > LineEndBuf(pInStream->rdbuf());
-    streambuf* pOrigInBuf = pInStream->rdbuf();
-    if(pInFormat && !(pInFormat->Flags() & READBINARY) && !(pInFormat->Flags() & READXML))
-      pOrigInBuf = pInStream->rdbuf(&LineEndBuf);
-    
     int count = Convert();
 
-    pInStream->rdbuf(pOrigInBuf);
     pOutStream = pOrigOutStream;
     return count;
   }
@@ -800,16 +791,25 @@ namespace OpenBabel {
     }
 #endif
 
-    FilteringInputStreambuf< LineEndingExtractor > LineEndBuf(pInStream->rdbuf());
-    streambuf* pOrigInBuf = pInStream->rdbuf();
-    if(!(pInFormat->Flags() & READBINARY) && !(pInFormat->Flags() & READXML))
-      pOrigInBuf = pInStream->rdbuf(&LineEndBuf);
-
-    pInStream->rdbuf(pOrigInBuf);
-
+    InstallStreamFilter();
     return pInFormat->ReadMolecule(pOb, this);
   }
 
+    void OBConversion::InstallStreamFilter()
+  {
+    //Do not install filtering input stream if a binary or XML format
+    //or if already installed in the current InStream (which may have changed).
+    //Deleting any old LErdbuf before contructing a new one ensures there is 
+    //only one for each OBConversion object. It is deleted in the destructor.
+
+    if(pInFormat && !(pInFormat->Flags() & (READBINARY | READXML)) && pInStream->rdbuf()!=pLineEndBuf)
+    {
+      delete pLineEndBuf;
+      pLineEndBuf = new LErdbuf(pInStream->rdbuf());
+      pInStream->rdbuf(pLineEndBuf);
+    }
+  }
+
   //////////////////////////////////////////////////
   /// Writes the object pOb but does not delete it afterwards.
   /// The output stream is lastingly changed if pos is not NULL
@@ -1022,7 +1022,7 @@ namespace OpenBabel {
     //If infile == outfile issue error message and return false
     //If name without the extensions are the same issue warning and return true;
     //Otherwise return true
-    bool ret=true;
+    // bool ret=true;
     string inname1, inname2;
     string::size_type pos;
     pos = infile.rfind('.');
