@@ -2,7 +2,7 @@
 rotamer.cpp - Handle rotamer list data.
  
 Copyright (C) 1998, 1999, 2000-2002 OpenEye Scientific Software, Inc.
-Some portions Copyright (C) 2001-2005 by Geoffrey R. Hutchison
+Some portions Copyright (C) 2001-2006 by Geoffrey R. Hutchison
  
 This file is part of the Open Babel project.
 For more information, see <http://openbabel.sourceforge.net/>
@@ -16,11 +16,9 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 ***********************************************************************/
+#include <openbabel/babelconfig.h>
 
-#include "rotamer.h"
-#include "mol.h"
-#include "obutil.h"
-#include "rotor.h"
+#include <openbabel/rotamer.h>
 
 #define OB_TITLE_SIZE     254
 #define OB_BINARY_SETWORD 32
@@ -30,6 +28,60 @@ using namespace std;
 namespace OpenBabel
 {
 
+  /** \class OBRotamerList rotamer.h <openbabel/rotamer.h>
+
+      A high-level class for rotamer / conformer generation, intended mainly
+      for use with the related class OBRotorList and the OBRotorRules database
+
+      Rotamers represent conformational isomers formed simply by rotation of
+      dihedral angles. On the other hand, conformers may include geometric
+      relaxation (i.e., slight modification of bond lengths, bond angles, etc.)
+
+      The following shows an example of generating 2 conformers using different
+      rotor states. Similar code could be used for systematic or Monte Carlo
+      conformer sampling when combined with energy evaluation (molecular
+      mechanics or otherwise).
+
+\code
+OBRotorList rl; // used to sample all rotatable bonds via the OBRotorRules data
+// If you want to "fix" any particular atoms (i.e., freeze them in space)
+// then set up an OBBitVec of the fixed atoms and call
+// rl.SetFixAtoms(bitvec);
+rl.Setup(mol);
+
+// How many rotatable bonds are there?
+cerr << " Number of rotors: " << rl.Size() << endl;
+
+// indexed from 1, rotorKey[0] = 0
+std::vector<int> rotorKey(rl.Size() + 1, 0);
+
+// each entry represents the configuration of a rotor
+// e.g. indexes into OBRotor::GetResolution() -- the different angles
+//   to sample for a rotamer search
+for (unsigned int i = 0; i < rl.Size() + 1; ++i)
+  rotorKey[i] = 0; // could be anything from 0 .. OBRotor->GetResolution().size()
+
+// The OBRotamerList can generate conformations (i.e., coordinate sets)
+OBRotamerList rotamers;
+rotamers.SetBaseCoordinateSets(mol);
+rotamers.Setup(mol, rl);
+
+rotamers.AddRotamer(rotorKey);
+rotorKey[1] = 2; // switch one rotor
+rotamers.AddRotamer(rotorKey);
+
+rotamers.ExpandConformerList(mol, mol.GetConformers());
+
+// change the molecule conformation
+mol.SetConformer(0); // rotorKey 0, 0, ...
+conv.Write(&mol);
+
+mol.SetConformer(1); // rotorKey 0, 2, ...
+
+\endcode
+
+  **/
+
 //test byte ordering
 static int SINT = 0x00000001;
 static unsigned char *STPTR = (unsigned char*)&SINT;
@@ -58,27 +110,79 @@ int Swab(int i)
     return(i);
 }
 
+OBGenericData* OBRotamerList::Clone(OBBase* newparent) const
+{
+	//Since the class contains OBAtom pointers, the new copy use
+	//these from the new molecule, newparent
+	OBMol* newmol = static_cast<OBMol*>(newparent);
+	
+	OBRotamerList *new_rml = new OBRotamerList;
+	new_rml->_attr = _attr;
+	new_rml->_type = _type;
+
+	//Set base coordinates
+	unsigned int k,l;
+	vector<double*> bc;
+	double *c=NULL;
+	double *cc=NULL;
+	for (k=0 ; k<NumBaseCoordinateSets() ; ++k)
+	{
+			c = new double [3*NumAtoms()];
+			cc = GetBaseCoordinateSet(k);
+			for (l=0 ; l<3*NumAtoms() ; ++l)
+					c[l] = cc[l];
+			bc.push_back(c);
+	}
+	if (NumBaseCoordinateSets())
+			new_rml->SetBaseCoordinateSets(bc,NumAtoms());
+
+	//Set reference array
+	unsigned char *ref = new unsigned char [NumRotors()*4];
+	if (ref)
+	{
+			GetReferenceArray(ref);
+			new_rml->Setup(*newmol,ref,NumRotors()); 
+			delete [] ref;
+	}
+
+	//Set Rotamers
+	unsigned char *rotamers = new unsigned char [(NumRotors()+1)*NumRotamers()];
+	if (rotamers)
+	{
+			vector<unsigned char*>::const_iterator kk;
+			unsigned int idx=0;
+			for (kk = _vrotamer.begin();kk != _vrotamer.end();++kk)
+			{
+					memcpy(&rotamers[idx],(const unsigned char*)*kk,sizeof(unsigned char)*(NumRotors()+1));
+					idx += sizeof(unsigned char)*(NumRotors()+1);
+			}
+			new_rml->AddRotamers(rotamers,NumRotamers());
+			delete [] rotamers;
+	}
+	return new_rml;
+}
+
 OBRotamerList::~OBRotamerList()
 {
     vector<unsigned char*>::iterator i;
-    for (i = _vrotamer.begin();i != _vrotamer.end();i++)
+    for (i = _vrotamer.begin();i != _vrotamer.end();++i)
         delete [] *i;
 
     vector<pair<OBAtom**,vector<int> > >::iterator j;
-    for (j = _vrotor.begin();j != _vrotor.end();j++)
+    for (j = _vrotor.begin();j != _vrotor.end();++j)
         delete [] j->first;
 
     //Delete the interal base coordinate list
     unsigned int k;
-    for (k=0 ; k<_c.size() ; k++)
+    for (k=0 ; k<_c.size() ; ++k)
         delete [] _c[k];
 }
 
-void OBRotamerList::GetReferenceArray(unsigned char *ref)
+void OBRotamerList::GetReferenceArray(unsigned char *ref)const
 {
     int j;
-    vector<pair<OBAtom**,vector<int> > >::iterator i;
-    for (j=0,i = _vrotor.begin();i != _vrotor.end();i++)
+		vector<pair<OBAtom**,vector<int> > >::const_iterator i;
+    for (j=0,i = _vrotor.begin();i != _vrotor.end();++i)
     {
         ref[j++] = (unsigned char)(i->first[0])->GetIdx();
         ref[j++] = (unsigned char)(i->first[1])->GetIdx();
@@ -92,12 +196,12 @@ void OBRotamerList::Setup(OBMol &mol,OBRotorList &rl)
     //clear the old stuff out if necessary
     _vres.clear();
     vector<unsigned char*>::iterator j;
-    for (j = _vrotamer.begin();j != _vrotamer.end();j++)
+    for (j = _vrotamer.begin();j != _vrotamer.end();++j)
         delete [] *j;
     _vrotamer.clear();
 
     vector<pair<OBAtom**,vector<int> > >::iterator k;
-    for (k = _vrotor.begin();k != _vrotor.end();k++)
+    for (k = _vrotor.begin();k != _vrotor.end();++k)
         delete [] k->first;
     _vrotor.clear();
 
@@ -123,8 +227,8 @@ void OBRotamerList::Setup(OBMol &mol,OBRotorList &rl)
 
     vector<double>::iterator n;
     vector<vector<double> >::iterator m;
-    for (m = _vres.begin();m != _vres.end();m++)
-        for (n = m->begin();n != m->end();n++)
+    for (m = _vres.begin();m != _vres.end();++m)
+        for (n = m->begin();n != m->end();++n)
             *n *= RAD_TO_DEG;
 }
 
@@ -133,12 +237,12 @@ void OBRotamerList::Setup(OBMol &mol,unsigned char *ref,int nrotors)
     //clear the old stuff out if necessary
     _vres.clear();
     vector<unsigned char*>::iterator j;
-    for (j = _vrotamer.begin();j != _vrotamer.end();j++)
+    for (j = _vrotamer.begin();j != _vrotamer.end();++j)
         delete [] *j;
     _vrotamer.clear();
 
     vector<pair<OBAtom**,vector<int> > >::iterator k;
-    for (k = _vrotor.begin();k != _vrotor.end();k++)
+    for (k = _vrotor.begin();k != _vrotor.end();++k)
         delete [] k->first;
     _vrotor.clear();
 
@@ -148,7 +252,7 @@ void OBRotamerList::Setup(OBMol &mol,unsigned char *ref,int nrotors)
 
     int refatoms[4];
     OBAtom **atomlist;
-    for (i = 0; i < nrotors; i++)
+    for (i = 0; i < nrotors; ++i)
     {
         atomlist = new OBAtom* [4];
         refatoms[0] = (int)ref[i*4  ];
@@ -168,14 +272,14 @@ void OBRotamerList::Setup(OBMol &mol,unsigned char *ref,int nrotors)
 void OBRotamerList::AddRotamer(double *c)
 {
     int idx,size;
-    double angle,res=255.0f/360.0f;
+    double angle,res=255.0/360.0;
     vector3 v1,v2,v3,v4;
 
     unsigned char *rot = new unsigned char [_vrotor.size()+1];
     rot[0] = (char) 0;
 
     vector<pair<OBAtom**,vector<int> > >::iterator i;
-    for (size=1,i = _vrotor.begin();i != _vrotor.end();i++,size++)
+    for (size=1,i = _vrotor.begin();i != _vrotor.end();++i,++size)
     {
         idx = (i->first[0])->GetCIdx();
         v1.Set(c[idx],c[idx+1],c[idx+2]);
@@ -187,10 +291,10 @@ void OBRotamerList::AddRotamer(double *c)
         v4.Set(c[idx],c[idx+1],c[idx+2]);
 
         angle = CalcTorsionAngle(v1,v2,v3,v4);
-        while (angle < 0.0f)
-            angle += 360.0f;
-        while (angle > 360.0f)
-            angle -= 360.0f;
+        while (angle < 0.0)
+            angle += 360.0;
+        while (angle > 360.0)
+            angle -= 360.0;
         rot[size] = (unsigned char)rint(angle*res);
     }
 
@@ -200,18 +304,41 @@ void OBRotamerList::AddRotamer(double *c)
 void OBRotamerList::AddRotamer(int *arr)
 {
     unsigned int i;
-    double angle,res=255.0f/360.0f;
+    double angle,res=255.0/360.0;
 
     unsigned char *rot = new unsigned char [_vrotor.size()+1];
     rot[0] = (unsigned char)arr[0];
 
-    for (i = 0;i < _vrotor.size();i++)
+    for (i = 0;i < _vrotor.size();++i)
     {
         angle = _vres[i][arr[i+1]];
-        while (angle < 0.0f)
-            angle += 360.0f;
-        while (angle > 360.0f)
-            angle -= 360.0f;
+        while (angle < 0.0)
+            angle += 360.0;
+        while (angle > 360.0)
+            angle -= 360.0;
+        rot[i+1] = (unsigned char)rint(angle*res);
+    }
+    _vrotamer.push_back(rot);
+}
+
+  void OBRotamerList::AddRotamer(std::vector<int> arr)
+  {
+    unsigned int i;
+    double angle,res=255.0/360.0;
+    
+    if (arr.size() != (_vrotor.size() + 1))
+      return; // wrong size key
+
+    unsigned char *rot = new unsigned char [_vrotor.size()+1];
+    rot[0] = (unsigned char)arr[0];
+
+    for (i = 0;i < _vrotor.size();++i)
+    {
+        angle = _vres[i][arr[i+1]];
+        while (angle < 0.0)
+            angle += 360.0;
+        while (angle > 360.0)
+            angle -= 360.0;
         rot[i+1] = (unsigned char)rint(angle*res);
     }
     _vrotamer.push_back(rot);
@@ -220,18 +347,18 @@ void OBRotamerList::AddRotamer(int *arr)
 void OBRotamerList::AddRotamer(unsigned char *arr)
 {
     unsigned int i;
-    double angle,res=255.0f/360.0f;
+    double angle,res=255.0/360.0;
 
     unsigned char *rot = new unsigned char [_vrotor.size()+1];
     rot[0] = (unsigned char)arr[0];
 
-    for (i = 0;i < _vrotor.size();i++)
+    for (i = 0;i < _vrotor.size();++i)
     {
         angle = _vres[i][(int)arr[i+1]];
-        while (angle < 0.0f)
-            angle += 360.0f;
-        while (angle > 360.0f)
-            angle -= 360.0f;
+        while (angle < 0.0)
+            angle += 360.0;
+        while (angle > 360.0)
+            angle -= 360.0;
         rot[i+1] = (unsigned char)rint(angle*res);
     }
     _vrotamer.push_back(rot);
@@ -243,7 +370,7 @@ void OBRotamerList::AddRotamers(unsigned char *arr,int nrotamers)
     int i;
 
     size = (unsigned int)_vrotor.size()+1;
-    for (i = 0;i < nrotamers;i++)
+    for (i = 0;i < nrotamers;++i)
     {
         unsigned char *rot = new unsigned char [size];
         memcpy(rot,&arr[i*size],sizeof(char)*size);
@@ -254,18 +381,18 @@ void OBRotamerList::AddRotamers(unsigned char *arr,int nrotamers)
 void OBRotamerList::ExpandConformerList(OBMol &mol,vector<double*> &clist)
 {
     unsigned int j;
-    double angle,invres=360.0f/255.0f;
+    double angle,invres=360.0/255.0;
     unsigned char *conf;
     vector<double*> tmpclist;
     vector<unsigned char*>::iterator i;
 
-    for (i = _vrotamer.begin();i != _vrotamer.end();i++)
+    for (i = _vrotamer.begin();i != _vrotamer.end();++i)
     {
         conf = *i;
         double *c = new double [mol.NumAtoms()*3];
         memcpy(c,clist[(int)conf[0]],sizeof(double)*mol.NumAtoms()*3);
 
-        for (j = 0;j < _vrotor.size();j++)
+        for (j = 0;j < _vrotor.size();++j)
         {
             angle = invres*((double)conf[j+1]);
             if (angle > 180.0)
@@ -277,7 +404,7 @@ void OBRotamerList::ExpandConformerList(OBMol &mol,vector<double*> &clist)
 
     //transfer the conf list
     vector<double*>::iterator k;
-    for (k = clist.begin();k != clist.end();k++)
+    for (k = clist.begin();k != clist.end();++k)
         delete [] *k;
     clist = tmpclist;
 }
@@ -286,18 +413,18 @@ void OBRotamerList::ExpandConformerList(OBMol &mol,vector<double*> &clist)
 vector<double*> OBRotamerList::CreateConformerList(OBMol& mol)
 {
     unsigned int j;
-    double angle,invres=360.0f/255.0f;
+    double angle,invres=360.0/255.0;
     unsigned char *conf;
     vector<double*> tmpclist;
     vector<unsigned char*>::iterator i;
 
-    for (i = _vrotamer.begin();i != _vrotamer.end();i++)
+    for (i = _vrotamer.begin();i != _vrotamer.end();++i)
     {
         conf = *i;
         double *c = new double [mol.NumAtoms()*3];
         memcpy(c,_c[(int)conf[0]],sizeof(double)*mol.NumAtoms()*3);
 
-        for (j = 0;j < _vrotor.size();j++)
+        for (j = 0;j < _vrotor.size();++j)
         {
             angle = invres*((double)conf[j+1]);
             if (angle > 180.0)
@@ -316,18 +443,18 @@ void OBRotamerList::SetBaseCoordinateSets(vector<double*> bc, unsigned int N)
     unsigned int i,j;
 
     //Clear out old data
-    for (i=0 ; i<_c.size() ; i++)
+    for (i=0 ; i<_c.size() ; ++i)
         delete [] _c[i];
     _c.clear();
 
     //Copy new data
     double *c = NULL;
     double *cc= NULL;
-    for (i=0 ; i<bc.size() ; i++)
+    for (i=0 ; i<bc.size() ; ++i)
     {
         c = new double [3*N];
         cc = bc[i];
-        for (j=0 ; j<3*N ; j++)
+        for (j=0 ; j<3*N ; ++j)
             c[j] = cc[j];
         _c.push_back(c);
     }
@@ -335,9 +462,9 @@ void OBRotamerList::SetBaseCoordinateSets(vector<double*> bc, unsigned int N)
 }
 
 //! Rotate the coordinates of 'atoms'
-//! such that tor == ang - atoms in 'tor' should be ordered such 
-//! that the 3rd atom is the pivot around which atoms rotate
-//! ang is in degrees
+//! such that tor == ang.
+//! Atoms in 'tor' should be ordered such that the 3rd atom is 
+//! the pivot around which atoms rotate (ang is in degrees)
 void SetRotorToAngle(double *c, OBAtom **ref,double ang,vector<int> atoms)
 {
   double v1x,v1y,v1z,v2x,v2y,v2z,v3x,v3y,v3z;
@@ -373,8 +500,8 @@ void SetRotorToAngle(double *c, OBAtom **ref,double ang,vector<int> atoms)
   if (c1mag*c2mag < 0.01) costheta = 1.0; //avoid div by zero error
   else costheta = (c1x*c2x + c1y*c2y + c1z*c2z)/(sqrt(c1mag*c2mag));
 
-  if (costheta < -0.999999) costheta = -0.999999f;
-  if (costheta >  0.999999) costheta =  0.999999f;
+  if (costheta < -0.999999) costheta = -0.999999;
+  if (costheta >  0.999999) costheta =  0.999999;
 			      
   if ((v2x*c3x + v2y*c3y + v2z*c3z) > 0.0) radang = -acos(costheta);
   else                                     radang = acos(costheta);
@@ -401,7 +528,7 @@ void SetRotorToAngle(double *c, OBAtom **ref,double ang,vector<int> atoms)
   //
   tx = c[tor[1]];ty = c[tor[1]+1];tz = c[tor[1]+2];
   vector<int>::iterator i;int j;
-  for (i = atoms.begin();i != atoms.end();i++)
+  for (i = atoms.begin();i != atoms.end();++i)
     {
       j = ((*i)-1)*3;
       c[j] -= tx;c[j+1] -= ty;c[j+2]-= tz;
@@ -416,7 +543,7 @@ void SetRotorToAngle(double *c, OBAtom **ref,double ang,vector<int> atoms)
 int PackCoordinate(double c[3],double max[3])
 {
     int tmp;
-    float cf;
+    double cf;
     cf = c[0];
     tmp  = ((int)(cf*max[0])) << 20;
     cf = c[1];
@@ -428,14 +555,14 @@ int PackCoordinate(double c[3],double max[3])
 
 void UnpackCoordinate(double c[3],double max[3],int tmp)
 {
-    float cf;
-    cf = (float)(tmp>>20);
+    double cf;
+    cf = (double)(tmp>>20);
     c[0] = cf;
     c[0] *= max[0];
-    cf = (float)((tmp&0xffc00)>>10);
+    cf = (double)((tmp&0xffc00)>>10);
     c[1] = cf;
     c[1] *= max[1];
-    cf = (float)(tmp&0x3ff);
+    cf = (double)(tmp&0x3ff);
     c[2] = cf;
     c[2] *= max[2];
 }
