@@ -13,12 +13,9 @@ else
 fi
 
 echo
-echo "Testing CML support..."
+echo "# Testing CML support..."
 if [ -f $cmltestdir/test.sh ]; then
-    cd $cmltestdir
-    source test.sh
-    cd ..
+    (cd $cmltestdir; source test.sh 2>/dev/null)
 else
-    echo "CML tests not found. Skipping test."
-    exit 77
+    echo "1..0 # skipping - CML test set not found"
 fi
