@@ -34,6 +34,7 @@ GNU General Public License for more details.
 #if HAVE_CONIO_H
 	#include <conio.h>
 #endif
+#include <cstdlib>
 
 #if !HAVE_STRNCASECMP
 extern "C" int strncasecmp(const char *s1, const char *s2, size_t n);
@@ -219,7 +220,7 @@ int main(int argc,char *argv[])
                               {
                                 apiConv.SetOutFormat(pAPI);
                                 apiConv.AddOption(nam+1, OBConversion::GENOPTIONS, txt.c_str());
-                                apiConv.Write(NULL);
+                                apiConv.Write(NULL, &std::cout);
                               }
                           }
                         else
